@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: buildhash.c,v 1.63 1994/10/26 05:12:25 geoff Exp $";
+    "$Id: buildhash.c,v 1.64 1995/01/08 23:23:26 geoff Exp $";
 #endif
 
 #define MAIN
@@ -49,6 +49,9 @@ static char Rcs_Id[] =
 
 /*
  * $Log: buildhash.c,v $
+ * Revision 1.64  1995/01/08  23:23:26  geoff
+ * Make the various file suffixes configurable for DOS purposes.
+ *
  * Revision 1.63  1994/10/26  05:12:25  geoff
  * Get rid of some duplicate declarations.
  *
@@ -135,8 +138,8 @@ int main (argc, argv)
     if (yyparse ())			/* Parse the language tables */
 	exit (1);
 
-    (void) sprintf (Cfile, "%s.cnt", Dfile);
-    (void) sprintf (Sfile, "%s.stat", Dfile);
+    (void) sprintf (Cfile, "%s%s", Dfile, COUNTSUFFIX);
+    (void) sprintf (Sfile, "%s%s", Dfile, STATSUFFIX);
 
     if (stat (Dfile, &dstat) < 0)
 	{
